################################################################################
#
#  Licensed Materials - Property of IBM
#  5698-B34  Copyright IBM Corp. 2008, 2011
#  All rights reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#    File: tivoli_eif/zOSEventSupport_rules.sh, OMNIbus, EventPump422
#    SID: 1.7
#    Date Modified: 11/11/28 04:59:28
#
#  Change History:
#    YY/MM/DD        Description
#    --------        -----------------------------------------------------------
#    08/09/26        Initial IBM Tivoli Event Pump for z/OS V4.2.0
#    08/10/13        RAR remove redonent omnibus in copy path
#    09/03/10        Defect 175022
#    10/10/07        Defect 178932
#    11/04/15        OA35980, Tivoli Netcool/OMNIbus 7.3 support
#    11/11/28        OA37991, Tivoli EIF Probe master rules file support
#
################################################################################
#
#  This script file copies all rules and lookup files from the current directory
#  to the $NCHOME/omnibus/probes/$ARCH directory.
#
################################################################################

################################################################################
#  Get platform
################################################################################
checkos()
{
    SYSTEM=`uname -s`
    OSVERSION=`uname -v`
    RELEASE=`uname -r`

    case $SYSTEM in
    SunOS)
        MAJOR=`echo $RELEASE | sed 's/\(.\).*/\1/'`
        if [ "4." = $MAJOR ]; then
            err "Unsupported version of SunOS"
        fi

        PROCESSOR=`uname -p`

        case $PROCESSOR in
        sparc)
            if [ ` echo $RELEASE | cut -f2 -d. ` -gt 5 ]; then
                # Post 2.5 may have special binaries
                SUFFIX=_2.6
            fi
            ARCH=solaris2
            ;;
        *)
            err "Unsupported processor for Solaris 2.x"
            ;;
        esac
        ;;
    AIX)
        case $OSVERSION in
        4)
            ARCH=aix4
            ;;
        5|6)
            ARCH=aix5
            ;;
        *)
            err "Unsupported version of AIX"
            ;;
        esac
        ;;
    HP-UX)
        RNUMBER=`echo $RELEASE | sed -e 's/.\.\(..\)\..*/\1/'`
        case $RNUMBER in
        10)
            ARCH=hpux10
            ;;
        11)
            ARCH=hpux11
            ;;
        *)
            err "Unsupported version of HP-UX"
            ;;
        esac
        ;;
    Linux)
        ARCH=`uname -m`
        RMAJOR=`echo $RELEASE | sed 's/\(.\).*/\1/'`
        case $ARCH in
        i*86|x86*)
            ARCH=linux"$RMAJOR"x86
            ;;
        s390*)
            ARCH=linux"$RMAJOR"s390
            ;;
        *)
            err "Unsupported processor for Linux"
            ;;
        esac
        ;;
    *)
        err "Unsupported platform"
        ;;
    esac
}

checkos;
cp -f *.rules $NCHOME/omnibus/probes/$ARCH
cp -f *.lookup $NCHOME/omnibus/probes/$ARCH
